@@ -227,10 +227,6 @@ class Helper
 		    $args['post__not_in'] = $settings['post__not_in'];
 	    }
 
-        if( 'product' === $post_type && function_exists('whols_lite') ){
-            $args['meta_query'] = array_filter( apply_filters( 'woocommerce_product_query_meta_query', $args['meta_query'], new \WC_Query() ) );
-        }
-
         return $args;
     }
 
@@ -775,9 +771,6 @@ class Helper
                     'value' => 'instock'
                 ];
             }
-            if( 'product' === $args['post_type'] && function_exists('whols_lite') ){
-                $args['meta_query'] = array_filter( apply_filters( 'woocommerce_product_query_meta_query', $args['meta_query'], new \WC_Query() ) );
-            }
         }
 
         return $args;
@@ -1057,7 +1050,7 @@ class Helper
 	 * @return array
 	 */
 	public static function eael_allowed_tags() {
-		return apply_filters( 'eael_allowed_tags', [
+		return [
 			'a'       => [
 				'href'   => [],
 				'title'  => [],
@@ -1066,7 +1059,6 @@ class Helper
 				'id'     => [],
 				'style'  => [],
 				'target' => [],
-				'data-elementor-open-lightbox' => [],
 			],
 			'q'       => [
 				'cite'  => [],
@@ -1291,7 +1283,7 @@ class Helper
 				'style' => [],
 				'align' => [],
 			],
-			'td'     => [
+			'td'      => [
 				'class'   => [],
 				'id'      => [],
 				'style'   => [],
@@ -1299,21 +1291,7 @@ class Helper
 				'colspan' => [],
 				'rowspan' => [],
 			],
-			'header' => [
-				'class' => [],
-				'id'    => [],
-				'style' => [],
-			],
-			'iframe' => [
-				'class'  => [],
-				'id'     => [],
-				'style'  => [],
-				'title'  => [],
-				'width'  => [],
-				'height' => [],
-				'src'    => []
-			]
-		] );
+		];
 	}
 
     /**
@@ -1480,37 +1458,6 @@ class Helper
 		}
 	}
 
-    /**
-     * Get all ordered products by the user
-     * @return boolean|array order ids
-     * @since 5.8.9
-     */
-    public static function eael_get_all_user_ordered_products() {
-        $user_id = get_current_user_id();
-
-        if( ! $user_id ) {
-            return false;
-        }
-
-        $args = array(
-            'customer_id' => $user_id,
-            'limit' => -1,
-        );
-
-        $orders = wc_get_orders($args);
-        $product_ids = [];
-
-        foreach( $orders as $order ){
-            $items = $order->get_items();
-            
-            foreach($items as $item){
-                $product_ids[] = $item->get_product_id();
-            }
-        }
-
-        return $product_ids;
-    }
-
 	/**
 	 * Get current device by screen size
 	 *
